@@ -11,6 +11,7 @@ Options:
     -h --help                       Show this help screen
     -s --settings SETTINGS_FILE     Settings file to load
     -m MESSAGE                      Add a message without opening your editor
+    -f                              Output path to braindump topic file
 """
 
 import json
@@ -30,7 +31,7 @@ def load_settings(settings_file=None):
         'default_topic': 'braindump',
         'editor': os.environ.get('EDITOR', 'vi'),
         'file_ext': '.txt',
-        'dumper': 'braindump.core.FSDumper',
+        'dumper': 'braindump.dumpers:FSDumper',
     }
 
     try:
@@ -48,7 +49,7 @@ def load_settings(settings_file=None):
 
 
 def get_dumper(dumper):
-    parts = dumper.rsplit('.', 1)
+    parts = dumper.rsplit(':', 1)
     _tmp = import_module(parts[0])
     return getattr(_tmp, parts[1])
 
@@ -75,5 +76,7 @@ def main():
     elif arguments['-m'] is not None:
         if not dumper.quick_add(topic, arguments['-m']):
             sys.exit('Unable to append message to dumpfile \'{0}\''.format(topic))
+    elif arguments['-f'] is True:
+        print dumper._get_topic_filename(topic)  # todo: let's not do this. plugin system, maybe?
     else:
         dumper.edit_topic(topic)
